==> charcoal-0.1.0-alpha.zip: charcoal-0.1.0-alpha/charcoal/core/Config.class.php <==
<?php
/**
* ͤݻ륯饹
*
* PHP version 5
*
* @package    core
* @author     stk2k <stk2k@sazysoft.com>
* @copyright  2008 stk2k, sazysoft
*/

class charcoal_Config
{
	private $_config;

	/*
	 *    󥹥ȥ饯
	 */
	public function __construct( $data = NULL )
	{
		$this->_config = $data ? $data : array();
	}

	/*
	 *
	 */
	public function isEmptry()
	{
		return (count($this->_config) == 0);
	}

	/*
	 *ɲ
	 */
	public function append( $add )
	{
		if ( $add ){
			if ( is_array( $add ) ){
				$this->_config = array_merge( $this->_config, $add );
			}
			else{
				$this->_config[] = $add;
			}
		}
	}

	/*
	 *쳬ؤΥ
	 */
	public function getKeys()
	{
		return array_keys( $this->_config );
	}

	/*
	 * ͤʸȤƼ
	 */
	public function getString( $key, $process_macro = NULL )
	{
		// ͤ
		$value = $this->_config[ $key ];

		// ̤ʤʸ֤
		if ( !$value ){
			return '';
		}

		// Ÿե饰FALSEξϤΤޤ֤
		if ( $process_macro == NULL || !$process_macro ){
			return $value;
		}

		// ޥŸֵ
		return charcoal_ConfigUtil::processMacro( $value );
	}

	/*
	 * ͤȤƼ
	 */
	public function getArray( $key )
	{
		// ͤ
		$value = $this->_config[ "$key" ];

		// ̤ʤ֤
		if ( !$value ){
			return array();
		}

		// ˤֵ
		return  $value;
	}

	/*
	 * ͤ֡ͤȤƼ
	 */
	public function getBoolean( $key )
	{
		// ͤ
		$value = $this->_config[ $key ];

		// ֡뷿ˤֵ
		return ( $value === 'on' );
	}

	/*
	 *ͤ
	 */
	public function dump( $key = NULL )
	{
		$title     = s(get_class($this));
		$line_end  = s('<BR>');
		$indent    = s('---');
		if ( $key ){
			// ΥФͤ
			$value = $this->_config[ $key ];
			System::dumpVar( $value, $title, $line_end, $indent );
		}
		else{
			// ٤Ƥͤ
			System::dumpArray( a($this->_config), $title, $line_end, $indent );
		}
	}

}

==> charcoal-0.2.0-alpha.zip: charcoal-0.2.0-alpha/charcoal/core/Config.class.php <==
<?php
/**
* ͤݻ륯饹
*
* PHP version 5
*
* @package    core
* @author     stk2k <stk2k@sazysoft.com>
* @copyright  2008 stk2k, sazysoft
*/

class charcoal_Config
{
	private $_config;

	/*
	 *    󥹥ȥ饯
	 */
	public function __construct( $data = NULL )
	{
		$this->_config = $data ? $data : array();
	}

	/*
	 *
	 */
	public function isEmptry()
	{
		return (count($this->_config) == 0);
	}

	/*
	 *ɲ
	 */
	public function append( $add )
	{
		if ( $add ){
			if ( is_array( $add ) ){
				$this->_config = array_merge( $this->_config, $add );
			}
			else{
				$this->_config[] = $add;
			}
		}
	}

	/*
	 *쳬ؤΥ
	 */
	public function getKeys()
	{
		return array_keys( $this->_config );
	}

	/*
	 * ͤʸȤƼ
	 */
	public function getString( $key, $process_macro = NULL )
	{
		// ̤ʤʸ֤
		if ( !isset($this->_config[ "$key" ]) ){
			return '';
		}

		// ͤ
		$value = $this->_config[ $key ];

		// Ÿե饰FALSEξϤΤޤ֤
		if ( $process_macro == NULL || !$process_macro ){
			return $value;
		}

		// ޥŸֵ
		return charcoal_ConfigUtil::processMacro( $value );
	}

	/*
	 * ͤȤƼ
	 */
	public function getArray( $key )
	{
		// ̤ʤ֤
		if ( !isset($this->_config[ "$key" ]) ){
			return array();
		}

		// ͤ
		$value = $this->_config[ "$key" ];

		// ˤֵ
		return  $value;
	}

	/*
	 * ͤ֡ͤȤƼ
	 */
	public function getBoolean( $key )
	{
		// ̤ʤFALSE֤
		if ( !isset($this->_config[ "$key" ]) ){
			return FALSE;
		}

		// ͤ
		$value = $this->_config[ $key ];

		// ֡뷿ˤֵ
		return ( $value === 'on' );
	}

	/*
	 *ͤ
	 */
	public function dump( $key = NULL )
	{
		$title     = s(get_class($this));
		$line_end  = s('<BR>');
		$indent    = s('---');
		if ( $key ){
			// ΥФͤ
			$value = $this->_config[ $key ];
			System::dumpVar( $value, $title, $line_end, $indent );
		}
		else{
			// ٤Ƥͤ
			System::dumpArray( a($this->_config), $title, $line_end, $indent );
		}
	}

}
